import tkinter as tk
from tkinter import Label
import GPUtil
import threading
import time

def update_gpu_info(label):
    while True:
        try:
            gpus = GPUtil.getGPUs()
            if gpus:
                # Collect GPU info for all GPUs
                gpu_info = ""
                for gpu in gpus:
                    gpu_usage = f"Usage: {gpu.load*100:.1f}%"
                    gpu_temp = f"Temp: {gpu.temperature}°C"
                    gpu_info += f"GPU {gpu.id}: {gpu_usage} | {gpu_temp}\n"
                label.config(text=gpu_info)
            else:
                label.config(text="GPU not found")
        except Exception as e:
            label.config(text=f"Error: {str(e)}")
        time.sleep(1)  # Update every second

def create_overlay():
    root = tk.Tk()
    root.overrideredirect(True)  # Remove window decorations
    root.geometry("+300+300")  # Initial position
    root.attributes('-topmost', True)  # Always on top
    root.attributes('-alpha', 0.8)  # Semi-transparency

    label = Label(root, text="GPU Info", font=('Helvetica', 16), fg='white', bg='black')
    label.pack(padx=20, pady=20)

    close_button = tk.Button(root, text="Close", command=root.destroy)
    close_button.pack(side='bottom', pady=10)

    # Make the window draggable
    def start_drag(event):
        root._drag_start_x = event.x
        root._drag_start_y = event.y

    def do_drag(event):
        x = root.winfo_pointerx() - root._drag_start_x
        y = root.winfo_pointery() - root._drag_start_y
        root.geometry(f"+{x}+{y}")

    label.bind("<Button-1>", start_drag)
    label.bind("<B1-Motion>", do_drag)

    threading.Thread(target=update_gpu_info, args=(label,), daemon=True).start()

    root.mainloop()

if __name__ == "__main__":
    create_overlay()
